@@ -23,12 +23,45 @@
 
 #include "optmanager.h"
 #include "../src/version.h"
+#include "qdltexporter.h"
+
 #include <QDebug>
 #include <QFileInfo>
 #include <iostream>
 
-// Global static pointer used to ensure a single instance of the class.
-//OptManager* OptManager::instance;
+namespace {
+Split parseSplitOption(const QString& splitOption) {
+    Split result;
+    result.size = splitOption.left(splitOption.length() - 1).toULong();
+    if (splitOption.endsWith("K")) {
+        result.unit = Units::KB;
+    } else if (splitOption.endsWith("M")) {
+        result.unit = Units::MB;
+    } else if (splitOption.endsWith("G")) {
+        result.unit = Units::GB;
+    } else {
+        throw std::runtime_error("Couldn't parse split option: " + splitOption.toStdString());
+    }
+    return result;
+}
+
+QString toString(const Split& split) {
+    QString result = QString::number(split.size);
+    switch (split.unit) {
+    case Units::KB:
+        result += "K";
+        break;
+    case Units::MB:
+        result += "M";
+        break;
+    case Units::GB:
+        result += "G";
+        break;
+    }
+    return result;
+}
+
+}
 
 OptManager::OptManager()
 {
@@ -37,18 +70,11 @@ OptManager::OptManager()
     convert = false;
     filter = false;
     convertionmode = e_ASCI;
-    delimiter = ',';
+    delimiter = QDLT_DEFAULT_EXPORT_DELIMITER;
+    signature = QDLT_DEFAULT_EXPORT_SIGNATURE;
     multifilter = false;
 }
 
-/*OptManager* OptManager::getInstance()
-{
-    if (!instance)
-        instance = new OptManager;
-
-    return instance;
-}*/
-
 OptManager::OptManager(OptManager const&)
 {
 
@@ -92,7 +118,9 @@ void OptManager::printUsage()
     qDebug()<<" -u\tConversion will be done in UTF8 instead of ASCII";
     qDebug()<<" -csv\tConversion will be done in CSV format";
     qDebug()<<" -d\tConversion will NOT be done, save in dlt file format again instead";
-    qDebug()<<" -delimiter <character>\tThe used delimiter for CSV export (Default: ,).";
+    qDebug()<<" -delimiter <character>\tThe used delimiter for CSV export (Default: "+QString(QDLT_DEFAULT_EXPORT_DELIMITER)+").";
+    qDebug()<<" -signature <string>\tThe used signature for CSV export, which columns are exported (Default: "+QString(QDLT_DEFAULT_EXPORT_SIGNATURE)+").  I=Index,T=Time,S=Timestamp,O=Count,E=Ecuid,A=Apid,C=Ctid,N=SessionId,Y=Type,U=Subtype,M=Mode,R=#Args,P=Payload";
+    qDebug()<<" -split <size>\t Output file size limit given in Kb, Mb or Gb (Default: infinity).";
     qDebug()<<" -multifilter\tMultifilter will generate a separate export file with the name of the filter.";
     qDebug()<<"             \t-c will define the folder name, not the filename.";
     qDebug()<<"\nExamples:\n";
@@ -100,11 +128,13 @@ void OptManager::printUsage()
     qDebug().noquote() << executable << "-c -u .\\trace.txt c:\\trace\\trace.dlt";
     qDebug().noquote() << executable << "-d -c .\\trace.dlt c:\\trace\\trace.dlt";
     qDebug().noquote() << executable << "-csv -c .\\trace.csv c:\\trace\\trace.dlt";
+    qDebug().noquote() << executable << "-csv -delimiter ; -signature TSEACP -c c:\\trace\\trace.csv c:\\trace\\trace.dlt";
     qDebug().noquote() << executable << "-d -c .\\filteredtrace.dlt c:\\filter\\filter.dlf c:\\trace\\trace.dlt";
     qDebug().noquote() << executable << "trace_1.dlt trace_2.dlt";
     qDebug().noquote() << executable << "input.pcap output.dlt";
     qDebug().noquote() << executable << "-c output.txt input.pcap";
-    qDebug().noquote() << executable << "-c output.txt input1.mf4 input2.mf4\n";
+    qDebug().noquote() << executable << "-c output.txt input1.mf4 input2.mf4";
+    qDebug().noquote() << executable << "-d -split 100K c:\\trace\\trace.dlt\n -c output.dlt";
 }
 
 void OptManager::parse(QStringList *opt)
@@ -153,49 +183,60 @@ void OptManager::parse(QStringList *opt)
 
             i += 1;
         }
-        else if(str.compare("-u")==0)
+        else if(str.compare("-signature")==0)
         {
+            QString c1 = opt->value(i+1);
+
+            signature = QString("%1").arg(c1).toLatin1();
+
+            qDebug() << "Signature:" << signature;
+
+            i += 1;
+        } else if (str.compare("-split") == 0) {
+            const QString c1 = opt->value(i + 1);
+            try {
+                split = parseSplitOption(c1);
+                qDebug() << "Split size: " << toString(split.value());
+            } catch (const std::runtime_error& e) {
+                qDebug() << e.what();
+            }
+
+            i += 1;
+        } else if (str.compare("-c") == 0) {
+            qDebug() << "Convert to ASCII";
+
+            convert = true;
+
+            convertSourceFile = QString("%1").arg(opt->at(i+1));
+            i += 1;
+        } else if (str.compare("-u") == 0) {
             qDebug() << "Convert to UTF8";
 
             convertionmode = e_UTF8;
-        }
-        else if(str.compare("-csv")==0)
-        {
+        } else if (str.compare("-csv") == 0) {
             qDebug() << "Convert to CSV";
 
             convertionmode = e_CSV;
-        }
-        else if(str.compare("-multifilter")==0)
-        {
+        } else if (str.compare("-multifilter") == 0) {
             qDebug() << "Multifilter export selected.";
 
             multifilter = true;
-        }
-        else if(str.compare("-d")==0)
-        {
+        } else if (str.compare("-d") == 0) {
             qDebug() << "Convert to DLT";
 
             convertionmode = e_DLT;
-        }
-        else if(opt->at(i).endsWith(".dlt") || opt->at(i).endsWith(".DLT"))
-        {
+        } else if (opt->at(i).endsWith(".dlt") || opt->at(i).endsWith(".DLT")) {
             const QString logFile = QString("%1").arg(opt->at(i));
             logFiles += logFile;
             qDebug()<< "DLT filename:" << logFile;
-        }
-        else if(opt->at(i).endsWith(".dlf") || opt->at(i).endsWith(".DLF"))
-        {
+        } else if (opt->at(i).endsWith(".dlf") || opt->at(i).endsWith(".DLF")) {
             filterFiles += QString("%1").arg(opt->at(i));
             qDebug()<< "Filter filename:" << QString("%1").arg(opt->at(i));
-        }
-        else if(opt->at(i).endsWith(".pcap") || opt->at(i).endsWith(".PCAP"))
-        {
+        } else if (opt->at(i).endsWith(".pcap") || opt->at(i).endsWith(".PCAP")) {
             const QString pcapFile = QString("%1").arg(opt->at(i));
             pcapFiles += pcapFile;
             qDebug()<< "Pcap filename:" << pcapFile;
-        }
-        else if(opt->at(i).endsWith(".mf4") || opt->at(i).endsWith(".MF4"))
-        {
+        } else if (opt->at(i).endsWith(".mf4") || opt->at(i).endsWith(".MF4")) {
             const QString mf4File = QString("%1").arg(opt->at(i));
             mf4Files += mf4File;
             qDebug()<< "MF4 filename:" << mf4File;
@@ -204,13 +245,33 @@ void OptManager::parse(QStringList *opt)
     } // end of for loop
 }
 
-bool OptManager::isLogFile(){return log;}
-bool OptManager::isFilterFile(){return filter;}
-bool OptManager::isConvert(){return convert;}
-bool OptManager::isMultifilter(){return multifilter;}
-e_convertionmode OptManager::get_convertionmode(){return convertionmode;}
-QStringList OptManager::getLogFiles(){return logFiles;}
-QStringList OptManager::getFilterFiles(){return filterFiles;}
-QString OptManager::getConvertSourceFile(){return convertSourceFile;}
-QString OptManager::getConvertDestFile(){return convertDestFile;}
-char OptManager::getDelimiter(){return delimiter;}
+bool OptManager::isLogFile() const {return log;}
+bool OptManager::isFilterFile() const {return filter;}
+bool OptManager::isConvert()const {return convert;}
+bool OptManager::isMultifilter() const {return multifilter;}
+e_convertionmode OptManager::getConvertionMode() const {return convertionmode;}
+QStringList OptManager::getLogFiles()const {return logFiles;}
+QStringList OptManager::getFilterFiles() const {return filterFiles;}
+QString OptManager::getConvertSourceFile() const {return convertSourceFile;}
+QString OptManager::getConvertDestFile()const {return convertDestFile;}
+char OptManager::getDelimiter() const {return delimiter;}
+QString OptManager::getSignature() const {return signature;}
+
+const std::optional<Split> &OptManager::getSplit() const
+{
+    return split;
+}
+
+std::size_t Split::toBytesCount() const
+{
+    switch (unit) {
+    case Units::KB:
+        return size * 1024;
+    case Units::MB:
+        return size * 1024 * 1024;
+    case Units::GB:
+        return size * 1024 * 1024 * 1024;
+    default:
+        return size;
+    }
+}
