@@ -188,6 +188,6 @@ void DltSystemViewerPlugin::updateProcesses(int , QDltMsg &msg)
 
 
 }
-#ifndef QT5
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
 Q_EXPORT_PLUGIN2(dltsystemviewerplugin, DltSystemViewerPlugin);
 #endif
