@@ -31,7 +31,7 @@ class DummyViewerPlugin : public QObject, QDLTPluginInterface, QDltPluginViewerI
     Q_OBJECT
     Q_INTERFACES(QDLTPluginInterface)
     Q_INTERFACES(QDltPluginViewerInterface)
-#ifdef QT5
+#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
     Q_PLUGIN_METADATA(IID "org.genivi.DLT.DummyViewerPlugin")
 #endif
 
