@@ -64,7 +64,7 @@
 #ifndef DLT_COMMON_H
 #define DLT_COMMON_H
 
-#include "export_rules.h"
+#include "export_c_rules.h"
 
 /**
   \defgroup commonapi DLT Common API
@@ -81,6 +81,8 @@
 
 #if !defined (__WIN32__) && !defined(_MSC_VER)
 #include <termios.h>
+#else
+typedef unsigned int speed_t;
 #endif
 
 #include "dlt_types.h"
