@@ -136,7 +136,7 @@ public:
     //! Apply RegEx Replace to the argumnets of a message, if any active in the filters.
     /*!
     */
-    bool applyRegExStringMsg(QDltMsg &msg);
+    bool applyRegExStringMsg(QDltMsg &msg) const;
 
 protected:
 private:
