@@ -2,29 +2,15 @@
 #include <QDebug>
 #include <QtEndian>
 
-/**
- * From QDlt.
- * Must be a "C" include to interpret the imports correctly
- * for MSVC compilers.
- **/
-#include "dlt_common.h"
 extern "C" {
-
-    #include "dlt_user.h"
+    #include "dlt_common.h"
 }
 
-#if defined(_MSC_VER)
-#include <io.h>
-#include <time.h>
-#include <WinSock.h>
-#else
-#include <unistd.h>     /* for read(), close() */
-#include <sys/time.h>	/* for gettimeofday() */
-#endif
-
 #include "qdltmsg.h"
 #include "qdltimporter.h"
 
+#include <time.h>
+
 QDltImporter::QDltImporter(QFile *outputfile, QStringList fileNames, QObject *parent) :
     QThread(parent)
 {
@@ -193,9 +179,8 @@ void QDltImporter::dltIpcFromMF4(QString fileName)
     }
 
     mdf_hdr_t mdfHeader,mdfDgHeader,mdfCgHeader,mdfCnHeader,mdfTxHeader;
-    mdf_dgblocklinks_t mdfDgBlockLinks;
+    mdf_dgblocklinks_t mdfDgBlockLinks = {};
     memset((char*)&mdfHeader,0,sizeof(mdf_hdr_t));
-    quint64 pos=0,hd_pos=0,dt_pos=0;
 
     if(inputfile.read((char*)&mdfHeader,sizeof(mdf_hdr_t))!=sizeof(mdf_hdr_t))
     {
@@ -204,11 +189,8 @@ void QDltImporter::dltIpcFromMF4(QString fileName)
         qDebug() << "fromMF4:" << "Size Error: Cannot read mdf header";
         return;
     }
-    if(!hd_pos && mdfHeader.id[0]=='#' && mdfHeader.id[1]=='#' && mdfHeader.id[2]=='H' && mdfHeader.id[3]=='D')
+    if(mdfHeader.id[0]=='#' && mdfHeader.id[1]=='#' && mdfHeader.id[2]=='H' && mdfHeader.id[3]=='D')
     {
-        pos = inputfile.pos() - sizeof(mdf_hdr_t);
-        //qDebug() << "HD:";
-        hd_pos=pos;
         if(inputfile.read((char*)&hdBlockLinks,sizeof(mdf_hdblocklinks_t))!=sizeof(mdf_hdblocklinks_t))
         {
             inputfile.close();
@@ -388,9 +370,7 @@ void QDltImporter::dltIpcFromMF4(QString fileName)
         }
         if(mdfHeader.id[0]=='#' && mdfHeader.id[1]=='#' && mdfHeader.id[2]=='D' && mdfHeader.id[3]=='T')
         {
-            pos = inputfile.pos() - sizeof(mdf_hdr_t);
-            //qDebug() << "DT:";
-            dt_pos=pos;
+            const auto pos = inputfile.pos() - sizeof(mdf_hdr_t);
             quint64 posDt=0;
             quint16 recordId;
             quint32 lengthVLSD;
@@ -513,17 +493,15 @@ void QDltImporter::dltIpcFromMF4(QString fileName)
                         }
                         if(!recordData.isEmpty())
                         {
-                            int pos = 0;
-                            quint64 time = hdBlockLinks.start_time_ns+ethFrame.timeStamp+(hdBlockLinks.hd_tz_offset_min+hdBlockLinks.hd_dst_offset_min)*60*1000000000;
-                            if(!dltFromEthernetFrame(recordData,pos,ethFrame.etherType,time/1000000000,time%1000000000/1000))
+                            quint64 time = hdBlockLinks.start_time_ns+ethFrame.timeStamp;
+                            if(!dltFromEthernetFrame(recordData,0,ethFrame.etherType,time/1000000000ul,time%1000000000ul/1000ul))
                             {
                                 inputfile.close();
                                 outputfile->close();
                                 qDebug() << "fromMF4: ERROR:" << "Size Error: Cannot read Ethernet Frame";
                                 return;
                             }
-                            pos = 0;
-                            if(!ipcFromEthernetFrame(recordData,pos,ethFrame.etherType,time/1000000000,time%1000000000/1000))
+                            if(!ipcFromEthernetFrame(recordData,0,ethFrame.etherType,time/1000000000ul,time%1000000000ul/1000ul))
                             {
                                 inputfile.close();
                                 outputfile->close();
@@ -610,8 +588,8 @@ void QDltImporter::dltIpcFromMF4(QString fileName)
                         if(!recordData.isEmpty())
                         {
                             int pos = 0;
-                            quint64 time = hdBlockLinks.start_time_ns+ethFrame.timeStamp+(hdBlockLinks.hd_tz_offset_min+hdBlockLinks.hd_dst_offset_min)*60*1000000000;
-                            if(!dltFromEthernetFrame(recordData,pos,ethFrame.etherType,time/1000000000,time%1000000000/1000))
+                            quint64 time = hdBlockLinks.start_time_ns+ethFrame.timeStamp;
+                            if(!dltFromEthernetFrame(recordData,pos,ethFrame.etherType,time/1000000000ul,time%1000000000ul/1000ul))
                             {
                                 inputfile.close();
                                 outputfile->close();
@@ -619,7 +597,7 @@ void QDltImporter::dltIpcFromMF4(QString fileName)
                                 return;
                             }
                             pos = 0;
-                            if(!ipcFromEthernetFrame(recordData,pos,ethFrame.etherType,time/1000000000,time%1000000000/1000))
+                            if(!ipcFromEthernetFrame(recordData,pos,ethFrame.etherType,time/1000000000ul,time%1000000000ul/1000ul))
                             {
                                 inputfile.close();
                                 outputfile->close();
@@ -685,8 +663,8 @@ void QDltImporter::dltIpcFromMF4(QString fileName)
                         if(!recordData.isEmpty())
                         {
                             int pos = 0;
-                            quint64 time = hdBlockLinks.start_time_ns+dltFrameBlock.timeStamp+(hdBlockLinks.hd_tz_offset_min+hdBlockLinks.hd_dst_offset_min)*60*1000000000;
-                            if(!dltFrame(recordData,pos,time/1000000000,time%1000000000/1000))
+                            quint64 time = hdBlockLinks.start_time_ns+dltFrameBlock.timeStamp;
+                            if(!dltFrame(recordData,pos,time/1000000000ul,time%1000000000ul/1000ul))
                             {
                                 inputfile.close();
                                 outputfile->close();
@@ -765,8 +743,8 @@ void QDltImporter::dltIpcFromMF4(QString fileName)
                         }
                         if(!recordData.isEmpty())
                         {
-                            quint64 time = hdBlockLinks.start_time_ns+plpRaw.timeStamp+(hdBlockLinks.hd_tz_offset_min+hdBlockLinks.hd_dst_offset_min)*60*1000000000;
-                            if(!ipcFromPlpRaw(&plpRaw,recordData,time/1000000000,time%1000000000/1000))
+                            quint64 time = hdBlockLinks.start_time_ns+plpRaw.timeStamp;
+                            if(!ipcFromPlpRaw(&plpRaw,recordData,time/1000000000ul,time%1000000000ul/1000ul))
                             {
                                 inputfile.close();
                                 outputfile->close();
@@ -807,6 +785,36 @@ void QDltImporter::dltIpcFromMF4(QString fileName)
     qDebug() << "fromMF4: Import finished";
 }
 
+DltStorageHeader QDltImporter::makeDltStorageHeader(std::optional<DltStorageHeaderTimestamp> ts)
+{
+    DltStorageHeader result;
+
+    result.pattern[0] = 'D';
+    result.pattern[1] = 'L';
+    result.pattern[2] = 'T';
+    result.pattern[3] = 0x01;
+
+    result.ecu[0] = 0;
+    result.ecu[1] = 0;
+    result.ecu[2] = 0;
+    result.ecu[3] = 0;
+
+    if (ts) {
+        result.seconds = static_cast<time_t>(ts->sec);
+        result.microseconds = static_cast<int32_t>(ts->usec);
+    } else {
+        if (struct timespec ts; timespec_get(&ts, TIME_UTC)) {
+            result.seconds = static_cast<uint32_t>(ts.tv_sec);
+            result.microseconds = static_cast<int32_t>(ts.tv_nsec / 1000);
+        } else {
+            result.seconds = 0;
+            result.microseconds = 0;
+        }
+    }
+
+    return result;
+}
+
 bool QDltImporter::ipcFromEthernetFrame(QByteArray &record,int pos,quint16 etherType,quint32 sec,quint32 usec)
 {
     if(etherType==0x9100 || etherType==0x88a8)
@@ -896,7 +904,7 @@ bool QDltImporter::ipcFromEthernetFrame(QByteArray &record,int pos,quint16 ether
                    // add PLP Header Data
                    QDltArgument arg1;
                    arg1.setTypeInfo(QDltArgument::DltTypeInfoRawd);
-                   arg1.setEndianness(QDltArgument::DltEndiannessLittleEndian);
+                   arg1.setEndianness(QDlt::DltEndiannessLittleEndian);
                    arg1.setOffsetPayload(0);
                    arg1.setData(record.mid(pos-sizeof(plp_header_data_t),sizeof(plp_header_data_t)));
                    msg.addArgument(arg1);
@@ -904,7 +912,7 @@ bool QDltImporter::ipcFromEthernetFrame(QByteArray &record,int pos,quint16 ether
                    // add IPC Header
                    QDltArgument arg2;
                    arg2.setTypeInfo(QDltArgument::DltTypeInfoRawd);
-                   arg2.setEndianness(QDltArgument::DltEndiannessLittleEndian);
+                   arg2.setEndianness(QDlt::DltEndiannessLittleEndian);
                    arg2.setOffsetPayload(0);
                    if(endOfSegment)
                    {
@@ -919,7 +927,7 @@ bool QDltImporter::ipcFromEthernetFrame(QByteArray &record,int pos,quint16 ether
                    // add IPC Data
                    QDltArgument arg3;
                    arg3.setTypeInfo(QDltArgument::DltTypeInfoRawd);
-                   arg3.setEndianness(QDltArgument::DltEndiannessLittleEndian);
+                   arg3.setEndianness(QDlt::DltEndiannessLittleEndian);
                    arg3.setOffsetPayload(0);
                    if(endOfSegment)
                    {
@@ -988,7 +996,7 @@ bool QDltImporter::ipcFromPlpRaw(mdf_plpRaw_t *plpRaw,QByteArray &record,quint32
                    // add PLP Header Data
                    QDltArgument arg1;
                    arg1.setTypeInfo(QDltArgument::DltTypeInfoRawd);
-                   arg1.setEndianness(QDltArgument::DltEndiannessLittleEndian);
+                   arg1.setEndianness(QDlt::DltEndiannessLittleEndian);
                    arg1.setOffsetPayload(0);
                    plp_header_data_t  plpHeaderData;
                    plpHeaderData.busSpecId=0;
@@ -1002,7 +1010,7 @@ bool QDltImporter::ipcFromPlpRaw(mdf_plpRaw_t *plpRaw,QByteArray &record,quint32
                    // add IPC Header
                    QDltArgument arg2;
                    arg2.setTypeInfo(QDltArgument::DltTypeInfoRawd);
-                   arg2.setEndianness(QDltArgument::DltEndiannessLittleEndian);
+                   arg2.setEndianness(QDlt::DltEndiannessLittleEndian);
                    arg2.setOffsetPayload(0);
                    if(endOfSegment)
                    {
@@ -1017,7 +1025,7 @@ bool QDltImporter::ipcFromPlpRaw(mdf_plpRaw_t *plpRaw,QByteArray &record,quint32
                    // add IPC Data
                    QDltArgument arg3;
                    arg3.setTypeInfo(QDltArgument::DltTypeInfoRawd);
-                   arg3.setEndianness(QDltArgument::DltEndiannessLittleEndian);
+                   arg3.setEndianness(QDlt::DltEndiannessLittleEndian);
                    arg3.setOffsetPayload(0);
                    if(endOfSegment)
                    {
@@ -1222,40 +1230,13 @@ bool QDltImporter::dltFromEthernetFrame(QByteArray &record,int pos,quint16 ether
 
 void QDltImporter::writeDLTMessageToFile(QByteArray &bufferHeader,char* bufferPayload,quint32 bufferPayloadSize,QString ecuId,quint32 sec,quint32 usec)
 {
-    DltStorageHeader str;
+    const auto timestamp =
+        (sec || usec) ? std::optional<DltStorageHeaderTimestamp>({sec, usec}) : std::nullopt;
+    DltStorageHeader str = makeDltStorageHeader(timestamp);
 
-    str.pattern[0]='D';
-    str.pattern[1]='L';
-    str.pattern[2]='T';
-    str.pattern[3]=0x01;
-    str.ecu[0]=0;
-    str.ecu[1]=0;
-    str.ecu[2]=0;
-    str.ecu[3]=0;
-
-    if (sec || usec)
-    { // todo should better use ptrs and not != 0
-        str.seconds = (time_t)sec;
-        str.microseconds = (int32_t)usec;
-    }
-    else
-    {
-#if defined(_MSC_VER)
-        struct timespec ts;
-        (void)timespec_get(&ts, TIME_UTC);
-        str.seconds = (time_t)ts.tv_sec;
-        str.microseconds = (int32_t)(ts.tv_nsec / 1000);
-#else
-        struct timeval tv;
-        gettimeofday(&tv, NULL);
-        str.seconds = (time_t)tv.tv_sec;        /* value is long */
-        str.microseconds = (int32_t)tv.tv_usec; /* value is long */
-#endif
-    }
     dlt_set_id(str.ecu, ecuId.toLatin1());
 
     outputfile->write((char*)&str,sizeof(DltStorageHeader));
     outputfile->write(bufferHeader);
     outputfile->write(bufferPayload,bufferPayloadSize);
-
 }
