@@ -4,11 +4,13 @@
 #include <QMap>
 #include <QThread>
 #include <QObject>
+#include <QFile>
 
 #include "export_rules.h"
-#include "qfile.h"
 #include "dlt_common.h"
 
+#include <optional>
+
 typedef struct pcap_hdr_s {
         quint32 magic_number;   /* magic number */
         quint16 version_major;  /* major version number */
@@ -171,6 +173,12 @@ public:
 
     void setOutputfile(QFile *newOutputfile);
 
+    struct DltStorageHeaderTimestamp {
+        quint32 sec;
+        quint32 usec;
+    };
+    static DltStorageHeader makeDltStorageHeader(std::optional<DltStorageHeaderTimestamp> timestamp = std::nullopt);
+
   private:
 
     bool dltFrame(QByteArray &record,int pos,quint32 sec = 0,quint32 usec = 0);
