@@ -19,9 +19,9 @@
  * @licence end@
  */
 
-#include <QApplication>
+//#include <QApplication>
 #include <QDir>
-#include <QMessageBox>
+//#include <QMessageBox>
 #include <QDateTime>
 #include <QStandardPaths>
 
@@ -67,10 +67,11 @@ QDltSettingsManager::QDltSettingsManager()
         if(!dir.mkpath(dir.absolutePath()))
         {
             /* creation of directory fails */
-            QMessageBox::critical(0, QString("DLT Viewer"),
+ /*           QMessageBox::critical(0, QString("DLT Viewer"),
                                            QString("Cannot create directory to store configuration!\n\n")+dir.absolutePath(),
                                            QMessageBox::Ok,
                                            QMessageBox::Ok);
+*/
         }
     }
 
@@ -130,11 +131,14 @@ void QDltSettingsManager::writeSettingsLocal(QXmlStreamWriter &xml)
             xml.writeTextElement("showPayload",QString("%1").arg(showPayload));
             xml.writeTextElement("showArguments",QString("%1").arg(showArguments));
             xml.writeTextElement("showMsgId",QString("%1").arg(showMsgId));
-            xml.writeTextElement("markercolor",QString("%1").arg(markercolor.name()));
+            xml.writeTextElement("markercolorRed",QString("%1").arg(markercolorRed));
+            xml.writeTextElement("markercolorGreen",QString("%1").arg(markercolorGreen));
+            xml.writeTextElement("markercolorBlue",QString("%1").arg(markercolorBlue));
         xml.writeEndElement(); // table
 
         xml.writeStartElement("other");
             xml.writeTextElement("autoConnect",QString("%1").arg(autoConnect));
+            xml.writeTextElement("supportDLTv2Decoding",QString("%1").arg(supportDLTv2Decoding));
             xml.writeTextElement("autoScroll",QString("%1").arg(autoScroll));
             xml.writeTextElement("autoMarkFatalError",QString("%1").arg(autoMarkFatalError));
             xml.writeTextElement("autoMarkWarn",QString("%1").arg(autoMarkWarn));
@@ -142,6 +146,7 @@ void QDltSettingsManager::writeSettingsLocal(QXmlStreamWriter &xml)
             xml.writeTextElement("updateContextLoadingFile",QString("%1").arg(updateContextLoadingFile));
             xml.writeTextElement("updateContextsUnregister",QString("%1").arg(updateContextsUnregister));
             xml.writeTextElement("loggingOnlyMode",QString("%1").arg(loggingOnlyMode));
+            xml.writeTextElement("loggingOnlyFilteredMessages",QString("%1").arg(loggingOnlyFilteredMessages));
             xml.writeTextElement("splitlogfile",QString("%1").arg(splitlogfile));
             xml.writeTextElement("fmaxFileSizeMB",QString("%1").arg(fmaxFileSizeMB));
             xml.writeTextElement("appendDateTime",QString("%1").arg(appendDateTime));
@@ -158,6 +163,7 @@ void QDltSettingsManager::writeSettings()
     settings->setValue("RefreshRate",RefreshRate);
     settings->setValue("StartUpMinimized",StartupMinimized);
     settings->setValue("ThemeSettings", static_cast<int>(themeSelectionSettings));
+    settings->setValue("msgCacheSize",msgCacheSize);
 
     /* Temporary directory */
     settings->setValue("tempdir/tempUseSystem", tempUseSystem);
@@ -181,15 +187,19 @@ void QDltSettingsManager::writeSettings()
     settings->setValue("startup/pluginsAutoloadPathName",pluginsAutoloadPathName);
     settings->setValue("startup/filterCache",filterCache);
     settings->setValue("startup/autoConnect",autoConnect);
+    settings->setValue("startup/supportDLTv2Decoding",supportDLTv2Decoding);
     settings->setValue("startup/autoScroll",autoScroll);
     settings->setValue("startup/autoMarkFatalError",autoMarkFatalError);
     settings->setValue("startup/autoMarkWarn",autoMarkWarn);
     settings->setValue("startup/autoMarkMarker",autoMarkMarker);
     settings->setValue("startup/loggingOnlyMode",loggingOnlyMode);
+    settings->setValue("startup/loggingOnlyFilteredMessages",loggingOnlyFilteredMessages);
     settings->setValue("startup/splitfileyesno",splitlogfile);
     settings->setValue("startup/maxFileSizeMB",fmaxFileSizeMB);
     settings->setValue("startup/appendDateTime",appendDateTime);
-    settings->setValue("startup/markercolor",markercolor.name());
+    settings->setValue("startup/markercolorRed",markercolorRed);
+    settings->setValue("startup/markercolorGreen",markercolorGreen);
+    settings->setValue("startup/markercolorBlue",markercolorBlue);
 
     /* table */
     settings->setValue("startup/fontSize",fontSize);
@@ -242,6 +252,10 @@ void QDltSettingsManager::readSettingsLocal(QXmlStreamReader &xml)
     {
         autoConnect = xml.readElementText().toInt();
     }
+    if(xml.name() == QString("supportDLTv2Decoding"))
+    {
+        supportDLTv2Decoding = xml.readElementText().toInt();
+    }
     if(xml.name() == QString("autoScroll"))
     {
         autoScroll = xml.readElementText().toInt();
@@ -358,9 +372,21 @@ void QDltSettingsManager::readSettingsLocal(QXmlStreamReader &xml)
     {
         loggingOnlyMode = xml.readElementText().toInt();
     }
-    if(xml.name() == QString("markercolor"))
+    if(xml.name() == QString("loggingOnlyFilteredMessages"))
     {
-        markercolor.setNamedColor(xml.readElementText());
+        loggingOnlyFilteredMessages = xml.readElementText().toInt();
+    }
+    if(xml.name() == QString("markercolorRed"))
+    {
+        markercolorRed = xml.readElementText().toInt();
+    }
+    if(xml.name() == QString("markercolorGreen"))
+    {
+        markercolorGreen = xml.readElementText().toInt();
+    }
+    if(xml.name() == QString("markercolorBlue"))
+    {
+        markercolorBlue = xml.readElementText().toInt();
     }
     if(xml.name() == QString("updateContextLoadingFile"))
     {
@@ -411,6 +437,7 @@ void QDltSettingsManager::readSettings()
     RefreshRate = settings->value("RefreshRate",DEFAULT_REFRESH_RATE).toInt();
     StartupMinimized = settings->value("StartupMinimized",0).toInt();
     themeSelectionSettings = static_cast<UI_Colour>(settings->value("ThemeSettings", 0).toInt());
+    msgCacheSize = settings->value("msgCacheSize",1000).toInt();
 
     /* startup */
     defaultProjectFile = settings->value("startup/defaultProjectFile",0).toInt();
@@ -425,15 +452,19 @@ void QDltSettingsManager::readSettings()
     pluginsAutoloadPathName = settings->value("startup/pluginsAutoloadPathName",QString("")).toString();
     filterCache = settings->value("startup/filterCache",1).toInt();
     autoConnect = settings->value("startup/autoConnect",0).toInt();
+    supportDLTv2Decoding = settings->value("startup/supportDLTv2Decoding",0).toInt();
     autoScroll = settings->value("startup/autoScroll",1).toInt();
     autoMarkFatalError = settings->value("startup/autoMarkFatalError",0).toInt();
     autoMarkWarn = settings->value("startup/autoMarkWarn",0).toInt();
     autoMarkMarker = settings->value("startup/autoMarkMarker",1).toInt();
     loggingOnlyMode = settings->value("startup/loggingOnlyMode",0).toInt();
+    loggingOnlyFilteredMessages = settings->value("startup/loggingOnlyFilteredMessages",0).toInt();
     splitlogfile = settings->value("startup/splitfileyesno",0).toInt();
     fmaxFileSizeMB = settings->value("startup/maxFileSizeMB",100).toFloat();
     appendDateTime = settings->value("startup/appendDateTime",0).toInt();
-    markercolor.setNamedColor(settings->value("startup/markercolor","#aaaaaa").toString() );
+    markercolorRed = settings->value("startup/markercolorRed",128).toInt();
+    markercolorGreen = settings->value("startup/markercolorGreen",128).toInt();
+    markercolorBlue = settings->value("startup/markercolorBlue",128).toInt();
 
     /* project table */
     fontSize = settings->value("startup/fontSize",8).toInt();
