@@ -45,10 +45,7 @@ int main(int argc, char *argv[])
     }
 
     QApplication a(argc, argv);
-
-    QStringList arguments = a.arguments();
-    QDltOptManager *opt = QDltOptManager::getInstance();
-    opt->parse(&arguments);
+    QDltOptManager::getInstance()->parse(a.arguments());
 
     MainWindow w;
     w.show();
