@@ -28,8 +28,16 @@
 #include <QColor>
 #include <QComboBox>
 #include <QProgressBar>
-#include <QCompleter>
-#include <QStringListModel>
+
+#include <QTableWidget>
+#include <QAbstractItemModel>
+#include <QStandardItemModel>
+#include <QHeaderView>
+
+
+#include <QTableWidget>
+#include <QAbstractItemModel>
+#include <QStandardItemModel>
 
 #include "tablemodel.h"
 #include "settingsdialog.h"
@@ -43,14 +51,6 @@
 #include "ui_mainwindow.h"
 #include "searchform.h"
 
-
-/**
- * When ecu items buffer size exceeds this while using
- * serial connection, it will be considered corrupted.
- **/
-
-#define DLT_BUFFER_CORRUPT_TRESHOLD 4* 1024
-
 /**
  * @brief Namespace to contain the toolbar positions.
  * You should always remember to update these enums if you
@@ -106,6 +106,8 @@ namespace Ui {
     class MainWindow;
 }
 
+struct EcuTree;
+
 class MainWindow : public QMainWindow
 {
     Q_OBJECT
@@ -116,7 +118,6 @@ public:
 
 private:
     Ui::MainWindow *ui;
-    QCompleter *newCompleter;
     /* Timer for connecting to ECUs */
     QTimer timer;
 
@@ -131,6 +132,7 @@ private:
     TableModel *tableModel;
     SearchTableModel *m_searchtableModel;
     WorkingDirectory workingDirectory;
+    bool filterIsChanged;
 
     /* Status line items */
     QLabel *statusFilename;
@@ -151,6 +153,10 @@ private:
     QShortcut *m_shortcut_searchprev;
     SearchForm* searchInput;
 
+    /* Shortcuts */
+    QShortcut *copyPayloadShortcut;
+    QShortcut *markShortcut;
+
     /* Export */
     ExporterDialog exporterDialog;
 
@@ -177,11 +183,10 @@ private:
     QStringList autoloadPluginsVersionStrings;
 
     /* String List Containing Search History */
-    enum { MaxSearchHistory = 50 };
+    enum { MaxSearchHistory = 20 };
     QAction *searchHistoryActs[MaxSearchHistory];
     QStringList searchHistory;
 
-
     /* Recent files */
     enum { MaxRecentFiles = 5 };
     QAction *recentFileActs[MaxRecentFiles];
@@ -247,13 +252,8 @@ private:
 
     void getSelectedItems(EcuItem **ecuitem,ApplicationItem** appitem,ContextItem** conitem);
 
-    /**
-        * @brief Reload the complete log file
-        * @param update if this parameter is false, the file is loaded the first time, if true the reload is performed because of a changed configuration
-        *
-        */
-    void reloadLogFileStop();
     void reloadLogFile(bool update=false, bool multithreaded = true);
+    void populateEcusTree(EcuTree&& ecuTree);
 
     void reloadLogFileDefaultFilter();
 
@@ -273,7 +273,7 @@ private:
     void controlMessage_SetTimingPackets(EcuItem* ecuitem, bool enable);
     void controlMessage_GetSoftwareVersion(EcuItem* ecuitem);
     void controlMessage_GetLogInfo(EcuItem* ecuitem);
-    void controlMessage_ReceiveControlMessage(EcuItem *ecuitem,QDltMsg &msg);
+    void controlMessage_ReceiveControlMessage(EcuItem *ecuitem, const QDltMsg &msg);
     void controlMessage_SetContext(EcuItem *ecuitem, QString apid, QString ctid,QString ctdescription,int log_level,int trace_status);
     void controlMessage_SetApplication(EcuItem *ecuitem, QString apid, QString appdescription);
     void controlMessage_Marker();
@@ -286,8 +286,7 @@ private:
     void updatePluginsECUList();
     void updatePlugins();
     void updatePlugin(PluginItem *item);
-    void contextLoadingFile(QDltMsg &msg);
-    void versionString(QDltMsg &msg);
+    void versionString(const QDltMsg &msg);
     void pluginsAutoload(QString version);
 
     void connectECU(EcuItem *ecuitem,bool force = false);
@@ -366,20 +365,15 @@ private:
     void restoreSelection();
     QList<int> previousSelection;
 
-    /* Disconnect and Reconnect serial connections */
-    QList<int> m_previouslyConnectedSerialECUs;
-    void saveAndDisconnectCurrentlyConnectedSerialECUs();
-    void connectPreviouslyConnectedECUs();
-
     /* default filters */
     void resetDefaultFilter();
 
-    QStringListModel m_CompleterModel;
-
     /* Get path from explorerView model index */
     QString getPathFromExplorerViewIndexModel(const QModelIndex &proxyIndex);
 
-    void writeDLTMessageToFile(QByteArray &bufferHeader,char*bufferPayload,quint32 bufferPayloadSize,EcuItem* ecuitem,quint32 sec=0,quint32 use=0);
+    void writeDLTMessageToFile(const QByteArray& bufferHeader, std::string_view payload,
+                               const EcuItem* ecuitem);
+
 
 protected:
     void keyPressEvent ( QKeyEvent * event ) override;
@@ -432,8 +426,6 @@ private slots:
     void on_actionAppend_triggered();
     void on_actionExport_triggered();
 
-    void on_pushButtonMovePluginUp_clicked();
-    void on_pushButtonMovePluginDown_clicked();
 
 public slots:
 
@@ -466,6 +458,7 @@ private slots:
     void on_action_menuHelp_Support_triggered();
     void on_action_menuHelp_Info_triggered();
     void on_action_menuHelp_Command_Line_triggered();
+    void on_actionShortcuts_List_triggered();
 
     // Config methods
     void on_action_menuConfig_Context_Delete_triggered();
@@ -482,7 +475,7 @@ private slots:
     void on_action_menuConfig_Disconnect_triggered();
     void on_action_menuConfig_Connect_triggered();
     void on_action_menuConfig_Delete_All_Contexts_triggered();
-    void onActionAenuConfigCopyPayloadToClipboardTriggered();
+    void onActionMenuConfigCopyPayloadToClipboardTriggered();
     void on_action_menuConfig_Copy_to_clipboard_triggered();
     void onActionMenuConfigCopyJiraToClipboardTriggered();
     void onActionMenuConfigCopyJiraHeadToClipboardTriggered();
@@ -626,14 +619,12 @@ public:
     QDltDefaultFilter defaultFilter;
 
     QStringList openFileNames;
-    QStringList list;
 
     /* store startLoggingDateTime when logging first data */
     QDateTime startLoggingDateTime;
 
 signals:
     void dltFileLoaded(const QStringList& paths);
-
 };
 
 #endif // MAINWINDOW_H
