@@ -2,12 +2,15 @@
 #define SEARCHFORM_H
 
 #include <QWidget>
+#include <QStringListModel>
+#include <QComboBox>
 
 namespace Ui {
 class SearchForm;
 }
 
 class QLineEdit;
+class QCompleter;
 
 class SearchForm : public QWidget
 {
@@ -27,12 +30,19 @@ public:
     void setState(State state);
     void setProgress(int val);
     void resetProgress();
+    void updateHistory();
+    void saveComboBoxSearchHistory();
+    void loadComboBoxSearchHistory();
 
 signals:
     void abortSearch();
 
 private:
     Ui::SearchForm *ui;
+
+    QCompleter *m_completer{nullptr};
+    QStringListModel m_historyModel;
+    enum { MaxComboBoxHistorySize = 20 };
 };
 
 #endif // SEARCHFORM_H
